@@ -37,6 +37,8 @@ from typing import (
     Union,
 )
 
+from deprecated import deprecated
+
 from opentelemetry import context as context_api
 from opentelemetry import trace as trace_api
 from opentelemetry.attributes import BoundedAttributes
@@ -55,7 +57,10 @@ from opentelemetry.sdk.resources import Resource
 from opentelemetry.sdk.trace import sampling
 from opentelemetry.sdk.trace.id_generator import IdGenerator, RandomIdGenerator
 from opentelemetry.sdk.util import BoundedList
-from opentelemetry.sdk.util.instrumentation import InstrumentationInfo
+from opentelemetry.sdk.util.instrumentation import (
+    InstrumentationInfo,
+    InstrumentationScope,
+)
 from opentelemetry.trace import SpanContext
 from opentelemetry.trace.status import Status, StatusCode
 from opentelemetry.util import types
@@ -357,11 +362,13 @@ class ReadableSpan:
         status: Status = Status(StatusCode.UNSET),
         start_time: Optional[int] = None,
         end_time: Optional[int] = None,
+        instrumentation_scope: InstrumentationScope = None,
     ) -> None:
         self._name = name
         self._context = context
         self._kind = kind
         self._instrumentation_info = instrumentation_info
+        self._instrumentation_scope = instrumentation_scope
         self._parent = parent
         self._start_time = start_time
         self._end_time = end_time
@@ -437,9 +444,16 @@ class ReadableSpan:
         return self._resource
 
     @property
+    @deprecated(
+        version="1.11.1", reason="You should use instrumentation_scope"
+    )
     def instrumentation_info(self) -> InstrumentationInfo:
         return self._instrumentation_info
 
+    @property
+    def instrumentation_scope(self) -> InstrumentationScope:
+        return self._instrumentation_scope
+
     def to_json(self, indent=4):
         parent_id = None
         if self.parent is not None:
@@ -729,6 +743,7 @@ class Span(trace_api.Span, ReadableSpan):
         record_exception: bool = True,
         set_status_on_exception: bool = True,
         limits=_UnsetLimits,
+        instrumentation_scope: InstrumentationScope = None,
     ) -> None:
         super().__init__(
             name=name,
@@ -737,6 +752,7 @@ class Span(trace_api.Span, ReadableSpan):
             kind=kind,
             resource=resource,
             instrumentation_info=instrumentation_info,
+            instrumentation_scope=instrumentation_scope,
         )
         self._sampler = sampler
         self._trace_config = trace_config
@@ -835,6 +851,7 @@ class Span(trace_api.Span, ReadableSpan):
             start_time=self._start_time,
             end_time=self._end_time,
             instrumentation_info=self._instrumentation_info,
+            instrumentation_scope=self._instrumentation_scope,
         )
 
     def start(
@@ -956,6 +973,7 @@ class Tracer(trace_api.Tracer):
         id_generator: IdGenerator,
         instrumentation_info: InstrumentationInfo,
         span_limits: SpanLimits,
+        instrumentation_scope: InstrumentationScope,
     ) -> None:
         self.sampler = sampler
         self.resource = resource
@@ -963,6 +981,7 @@ class Tracer(trace_api.Tracer):
         self.id_generator = id_generator
         self.instrumentation_info = instrumentation_info
         self._span_limits = span_limits
+        self._instrumentation_scope = instrumentation_scope
 
     @contextmanager
     def start_as_current_span(
@@ -1065,6 +1084,7 @@ class Tracer(trace_api.Tracer):
                 record_exception=record_exception,
                 set_status_on_exception=set_status_on_exception,
                 limits=self._span_limits,
+                instrumentation_scope=self._instrumentation_scope,
             )
             span.start(start_time=start_time, parent_context=context)
         else:
@@ -1127,6 +1147,11 @@ class TracerProvider(trace_api.TracerProvider):
                 schema_url,
             ),
             self._span_limits,
+            InstrumentationScope(
+                instrumenting_module_name,
+                instrumenting_library_version,
+                schema_url,
+            ),
         )
 
     def add_span_processor(self, span_processor: SpanProcessor) -> None:
